@@ -1,8 +1,12 @@
 #![doc(html_root_url = "https://docs.rs/wasm-bindgen-shared/0.2")]
 
-// The schema is so unstable right now we just force it to change whenever this
-// package's version changes, which happens on all publishes.
-pub const SCHEMA_VERSION: &str = env!("CARGO_PKG_VERSION");
+#[cfg(test)]
+mod schema_hash_approval;
+
+// This gets changed whenever our schema changes.
+// At this time versions of wasm-bindgen and wasm-bindgen-cli are required to have the exact same
+// SCHEMA_VERSION in order to work together.
+pub const SCHEMA_VERSION: &str = "0.2.74";
 
 #[macro_export]
 macro_rules! shared_api {
@@ -22,7 +26,7 @@ macro_rules! shared_api {
 
         struct Import<'a> {
             module: ImportModule<'a>,
-            js_namespace: Option<&'a str>,
+            js_namespace: Option<Vec<String>>,
             kind: ImportKind<'a>,
         }
 
@@ -100,16 +104,20 @@ macro_rules! shared_api {
             name: &'a str,
             variants: Vec<EnumVariant<'a>>,
             comments: Vec<&'a str>,
+            generate_typescript: bool,
         }
 
         struct EnumVariant<'a> {
             name: &'a str,
             value: u32,
+            comments: Vec<&'a str>,
         }
 
         struct Function<'a> {
             arg_names: Vec<String>,
+            asyncness: bool,
             name: &'a str,
+            generate_typescript: bool,
         }
 
         struct Struct<'a> {
@@ -117,12 +125,14 @@ macro_rules! shared_api {
             fields: Vec<StructField<'a>>,
             comments: Vec<&'a str>,
             is_inspectable: bool,
+            generate_typescript: bool,
         }
 
         struct StructField<'a> {
             name: &'a str,
             readonly: bool,
             comments: Vec<&'a str>,
+            generate_typescript: bool,
         }
 
         struct LocalModule<'a> {
